# AlterationSummaryResponse

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**work_reference_number** | **str** |  | 
**permit_reference_number** | **str** |  | 
**alteration_reference_number** | **str** |  | 
**street** | **str** |  | 
**town** | **str** |  | 
**area** | **str** |  | 
**location_description** | **str** |  | 
**highway_authority** | **str** |  | 
**promoter** | **str** |  | 
**work_status** | [**WorkStatusResponse**](WorkStatusResponse.md) |  | 
**work_status_string** | **str** |  | 
**proposed_start_date** | **datetime** |  | 
**proposed_end_date** | **datetime** |  | 
**proposed_start_time** | **datetime** |  | [optional] 
**proposed_end_time** | **datetime** |  | [optional] 
**work_category** | [**WorkCategoryResponse**](WorkCategoryResponse.md) |  | 
**work_category_string** | **str** |  | 
**alteration_status** | [**AlterationStatusResponse**](AlterationStatusResponse.md) |  | 
**alteration_status_string** | **str** |  | 
**alteration_type** | [**AlterationTypeResponse**](AlterationTypeResponse.md) |  | 
**alteration_type_string** | **str** |  | 
**date_created** | **datetime** |  | 
**deadline_date** | **datetime** |  | 
**status_changed_date** | **datetime** |  | 
**lane_rental_assessment_outcome** | **AllOfAlterationSummaryResponseLaneRentalAssessmentOutcome** |  | [optional] 
**lane_rental_assessment_outcome_string** | **str** |  | [optional] 
**lane_rental_charges_not_agreed** | **bool** |  | 
**lane_rental_charges_potentially_apply** | **bool** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

